## Adrienne Hosek and Lauren Peritz ----------------------------------------
## QJPS 2021 "Local labor markets and party elite"
## Purpose: Replicate Figures 1 and 2
## Update: 15 June 2021

## Preliminary steps -------------------------------------------------------
rm(list=ls(all=T))

# Set your working directory here in place of "~/MyFilePath"
setwd("~/MyFilePath/AH_LP_qjps2021_replication")

# packages
require(scales)

# Load sponsorship data 
load("HouseSponsorData.RData")

# drop neutral bills
dtr <- d[d$policy.content.final!= 0,]


##########################################################################
## Figure 1 --------------------------------------------------------------
## Gatekeeping, policy content of bills at each legislative stage 



# number of introduced bills, reported, passed house, law
introduced <- with(subset(dtr, duty == 0), do.call(rbind, tapply(policy.content.final, congress, function(k) table(k)/length(k), simplify = T)))

reported <- rbind(with(subset(dtr, duty == 0 & latest.action %in% c("comm_report", "passhouse", "law")), do.call(rbind, tapply(as.factor(policy.content.final), congress, function(k) table(k)/length(k), simplify = T))), c(0,0))[c(1:4,6,5),]
rownames(reported) <- 109:114

housepassed <- rbind(with(subset(dtr, duty == 0 & latest.action %in% c("passhouse", "law")), do.call(rbind, tapply(as.factor(policy.content.final), congress, function(k) table(k)/length(k), simplify = T))), c(0,0))[c(1:4,6,5),]
rownames(housepassed) <- 109:114

law <- rbind(with(subset(dtr, duty == 0 & latest.action == "law"), do.call(rbind, tapply(as.factor(policy.content.final), congress, function(k) table(k)/length(k), simplify = T))), c(0,0))[c(1:4,6,5),]
rownames(law) <- 109:114

labs <- apply(with(subset(dtr, duty == 0), table(congress, latest.action))[ , c(5:1)], 1, cumsum)[-4,][4:1,]


# plot bill progression and policy position by congress
c = 1.2
pdf("Figure1.pdf")
par(mar = c(4,4.5,1,1))
plot(x = 999, y = 999, ylim = c(0, c*6), xlim = c(0,4), xlab = NA, ylab = NA, axes= F)

for(i in c(1:6)){
  h = c*6 - 1 - c*(i - 1)
  segments(0, .5 + h, 4, .5 + h, lty = "dashed")
  
  rect(0, h, 1, h + introduced[i,1], col = alpha("grey", .5), border = NA)
  rect(0, h + 1 - introduced[i, 2], 1, h + 1, col = alpha("black", .4), border = NA)
  
  rect(1, h, 2, h + reported[i,1], col = alpha("grey", .5), border = NA)
  rect(1, h + 1 - reported[i, 2], 2, h + 1, col = alpha("black", .4), border = NA)
  
  rect(2, h + 0, 3, h + housepassed[i, 1], col = alpha("grey", .5), border = NA)
  rect(2, h + 1 - housepassed[i, 2], 3, h + 1, col = alpha("black", .4), border = NA)
  
  rect(3, h + 0, 4, h + law[i,1], col = alpha("grey", .5), border = NA)
  rect(3, h + 1 - law[i, 2], 4, h + 1, col = alpha("black", .4), border = NA)
  
  text(c(1:4) - .5, rep(.5 + h, 4), labels = labs[,i], pos = 3)
}

mtext(paste(c(109:114), paste("th", c("Rep", "Dem", "Dem", "Rep", "Rep", "Rep"), sep = ", "), sep=""), side = 2, at = 6.7 - c(0:5)*1.2, las = 2)
abline(v = c(0,1,2,3,4))
mtext(c("introduced", "reported", "pass house", "law"), side = 1, at = c(0:3)+.5)
dev.off()


paste(c(109:114), paste("th", c("Rep", "Dem", "Dem", "Rep", "Rep", "Rep"), sep = ", "), sep="")



## Figure 1 Descriptive Statistics ---------------------------------------------------
## Fischer exact test on difference in proportion of liberalizing bills 
## Introduced v. commitee-reported

#fischer exact test on whether the probability of being reported out of committee is no different than the probability of liberalizing bill being introduced in each congress.
#excludes neutral and duty bills

#proportion of bills that are liberalizing upon introduction - estimate probability liberalizing
phat <- with(subset(dtr, duty == 0), do.call(rbind, tapply(policy.content.final, congress, function(k) table(k)/length(k), simplify = T)))[,1]

#number of bills introduced by policy content 
introduced <- with(subset(dtr, duty == 0), do.call(rbind, tapply(policy.content.final, congress, function(k) table(k), simplify = T)))
introduced <- data.frame(introduced, total = rowSums(introduced))
colnames(introduced) <- c("lib", "prot", "total")

# number of bills reported, need to add zeros for 113th congress
reported <- rbind(with(subset(dtr, duty == 0 & latest.action %in% c("comm_report", "passhouse", "law")), do.call(rbind, tapply(as.factor(policy.content.final), congress, function(k) table(k), simplify = T))), c(0,0))[c(1:4,6,5), ]
rownames(reported) <- 109:114
reported <- data.frame(reported, total = rowSums(reported))
colnames(reported) <- c("lib", "prot", "total")

#under null hypothesis that there is no difference in the probability of the bill being liberalizing between introduced and reported groups.
#and alternative hypothesis that liberalizing bills more likely to be reported
res <- round(pbinom(q = reported$lib, size = reported$total, prob = phat, lower.tail = FALSE, log.p = FALSE),3)
names(res) <- 109:114 
res

#difference between Republican and Democratic-controlled House in number of liberalizing and protectionist bills reported out of committee
with(subset(dtr, duty == 0 & latest.action %in% c("comm_report", "passhouse", "law")), tapply(as.factor(policy.content.final), ifelse(congress %in% c(109, 112:114), 0, 1), function(k) table(k), simplify = T))

#difference between Republican and Democratic-controlled House in number of liberalizing and protectionist bills passed by the House
with(subset(dtr, duty == 0 & latest.action %in% c("passhouse", "law")), tapply(as.factor(policy.content.final), ifelse(congress %in% c(109, 112:114), 0, 1), function(k) table(k), simplify = T))



##########################################################################
## Figure 2 --------------------------------------------------------------
## Introduced bills v. bills with roll call votes 


## Roll call voting data
load("HouseRollCallData.RData")
drc <- d

## policy content by party by congress

## all introduced bills
y <- as.numeric(with(subset(dtr, duty == 0), tapply(policy.content.final, list(congress, dem), mean)))
size <- sqrt(as.numeric(with(subset(dtr, duty == 0), tapply(policy.content.final, list(congress, dem), length))))

## bills with roll call votes
rollcallbills <- unique(drc$billno_unique)

yRC <- as.numeric(rbind(with(subset(dtr, duty == 0 & billno_unique %in% rollcallbills), tapply(policy.content.final, list(congress, dem), mean)), c(0,0))[c(1:4,6,5), ])
yRC[is.na(yRC)] <- 9999

sizeRC <- sqrt(as.numeric(rbind(with(subset(dtr, duty == 0 & billno_unique %in% rollcallbills), tapply(policy.content.final, list(congress, dem), length)), c(0,0))[c(1:4,6,5), ]))
sizeRC[is.na(sizeRC)] <- 0

## plot
pdf("Figure2.pdf")
par(mar = c(5,4,1,1))
plot(c(109:114), y[1:6], type = "l", axes = F, xlab = "congress", ylab = "mean policy position", pch = 19, ylim = c(-1,1), xlim = c(108,115), cex.lab = 1.2)
lines(c(109:114), y[7:12], type = "l", pch = 19)

points(c(109:114), y[1:6], col = rgb(1,0,0, alpha = .5), pch = 19, cex = size[1:6])
points(c(109:114), y[7:12], col = rgb(0,0,1, alpha = .5), pch = 19, cex = size[7:12])

points(c(109:114), yRC[1:6], col = rgb(.8,0,0, alpha = 1), pch = 19, cex = sizeRC[1:6])
points(c(109:114), yRC[7:12], col = rgb(0,0,.8, alpha = 1), pch = 19, cex = sizeRC[7:12])

axis(1, at = c(109:114), labels = NA)

mtext(c(109:114), side = 1, at = c(109:114), col = c("red", "blue", "blue", "red", "red", "red"), line = .5)

axis(2, at= c(-1, 0 , 1))
mtext("liberalizing", side = 1, at = 107.7, cex = 1.2)
mtext("protectionist", side = 3, at = 107.7, cex = 1.2)
dev.off()



